@@ -1,18 +1,15 @@
 use strict;
 use warnings;
 package MouseX::Role::Loggable;
-{
-  $MouseX::Role::Loggable::VERSION = '0.112001';
-}
 # ABSTRACT: Extensive, yet simple, logging role using Log::Dispatchouli
-
+$MouseX::Role::Loggable::VERSION = '0.113';
 use Carp;
 use Safe::Isa;
 use Mouse::Role;
 use Mouse::Util::TypeConstraints;
 use MouseX::Types::Mouse qw<Bool Str>;
 use Log::Dispatchouli;
-use namespace::sweep;
+use namespace::autoclean;
 
 class_type 'Log::Dispatchouli';
 class_type 'Log::Dispatchouli::Proxy';
@@ -192,13 +189,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MouseX::Role::Loggable - Extensive, yet simple, logging role using Log::Dispatchouli
 
 =head1 VERSION
 
-version 0.112001
+version 0.113
 
 =head1 SYNOPSIS
 
@@ -465,7 +464,7 @@ Michael G Schwern <schwern@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Michael G Schwern.
+This software is copyright (c) 2015 by Michael G Schwern.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
